Method: Pr2_controllers_msgs::Pr2GripperCommandGoal#initialize
- Defined in:
- lib/pr2_controllers_msgs/Pr2GripperCommandGoal.rb
#initialize(args = {}) ⇒ Pr2GripperCommandGoal
Constructor. You can set the default values using keyword operators.
43 44 45 46 47 48 49 50 |
# File 'lib/pr2_controllers_msgs/Pr2GripperCommandGoal.rb', line 43 def initialize(args={}) # message fields cannot be None, assign default values for those that are if args[:command] @command = args[:command] else @command = Pr2_controllers_msgs::Pr2GripperCommand.new end end |